import Taro, { Component } from '@tarojs/taro'
import echarts from '../ec-canvas/echarts'

function initChart(callback) {
  return function (canvas, width, height) {
    const chart = echarts.init(canvas, null, {
      width: width,
      height: height
    });
    canvas.setChart(chart);
    callback && callback(chart);
    return chart;
  }
}

/**
 * 传入 source 的格式为 [{ name: xxx, value: xxx }, {}]
 */
export default class LineChart extends Component {
  config = {
    usingComponents: {
      "ec-canvas": "../ec-canvas/ec-canvas"
    }
  }

  // this.echart
  echart = null

  state = {
    ec: { onInit: initChart(this.handleChart.bind(this)) },
  }

  // 禁止 props 变更时渲染
  shouldComponentUpdate(nextProps) {
    if (nextProps.source && nextProps.source.length) {
      this.refreshChart(this.props.source)
    }

    return false
  }

  handleChart (chart) {
    this.echart = chart
    if (!this.props.source || !this.props.source.length) {
      this.echart.showLoading()
    } else {
      this.refreshChart(this.props.source)
    }
  }

  refreshChart(source) {
    if (!this.echart) {
      console.warn('echarts not ready')
      return;
    }

    const defaultOpt = {
      color: ['#BB9C79', '#666666'],
      tooltip: {},
      xAxis: {type: 'category'},
      yAxis: {},
      dataset: {},
      series: [],
    }

    const options = {
      ...defaultOpt,
      dataset: { source },
      series: {
        type: 'line',
        dimensions: [ 'name' ],
      },
    }

    this.echart.setOption(options)
    this.echart.hideLoading()
  }

  render() {
    return (
      <ec-canvas style="width: 100%; height: 100%" ec={this.state.ec}></ec-canvas>)
  }
}
